aboutsummaryrefslogtreecommitdiffhomepage
path: root/src
diff options
context:
space:
mode:
authorJ08nY2023-02-10 23:55:24 +0100
committerJ08nY2023-02-10 23:55:24 +0100
commit564d640e49a822cd56fb8ef637af43c07719e8ce (patch)
tree28d6795d56e6ead05d73a4727c083b6cc92b6d5c /src
parent42da9317b2bdad37fa08c7f0984a494ab65edf89 (diff)
downloadsec-certs-564d640e49a822cd56fb8ef637af43c07719e8ce.tar.gz
sec-certs-564d640e49a822cd56fb8ef637af43c07719e8ce.tar.zst
sec-certs-564d640e49a822cd56fb8ef637af43c07719e8ce.zip
Fix typo auxillary -> auxiliary.
Diffstat (limited to 'src')
-rw-r--r--src/sec_certs/cli.py6
-rw-r--r--src/sec_certs/dataset/__init__.py2
-rw-r--r--src/sec_certs/dataset/cc.py40
-rw-r--r--src/sec_certs/dataset/dataset.py82
-rw-r--r--src/sec_certs/dataset/fips.py26
5 files changed, 78 insertions, 78 deletions
diff --git a/src/sec_certs/cli.py b/src/sec_certs/cli.py
index 96347787..08ef6abd 100644
--- a/src/sec_certs/cli.py
+++ b/src/sec_certs/cli.py
@@ -102,9 +102,9 @@ def build_or_load_dataset(
steps = [
ProcessingStep(
"process-aux-dsets",
- "process_auxillary_datasets",
+ "process_auxiliary_datasets",
preconditions=["meta_sources_parsed"],
- precondition_error_msg="Error: You want to process the auxillary datasets, but the data from cert. framework website was not parsed. You must use 'build' action first.",
+ precondition_error_msg="Error: You want to process the auxiliary datasets, but the data from cert. framework website was not parsed. You must use 'build' action first.",
pre_callback_func=None,
),
ProcessingStep(
@@ -124,7 +124,7 @@ steps = [
ProcessingStep(
"analyze",
"analyze_certificates",
- preconditions=["pdfs_converted", "auxillary_datasets_processed"],
+ preconditions=["pdfs_converted", "auxiliary_datasets_processed"],
precondition_error_msg="Error: You want to process txt documents of certificates, but pdfs were not converted. You must use 'convert' action first.",
pre_callback_func=None,
),
diff --git a/src/sec_certs/dataset/__init__.py b/src/sec_certs/dataset/__init__.py
index d5f93c78..c557c630 100644
--- a/src/sec_certs/dataset/__init__.py
+++ b/src/sec_certs/dataset/__init__.py
@@ -1,4 +1,4 @@
-"""This package exposes Datasets of various Samples, both primary (Common Criteria, FIPS) and auxillary (CVEs, CPEs, ...)"""
+"""This package exposes Datasets of various Samples, both primary (Common Criteria, FIPS) and auxiliary (CVEs, CPEs, ...)"""
from sec_certs.dataset.cc import CCDataset, CCDatasetMaintenanceUpdates, CCSchemeDataset
from sec_certs.dataset.cpe import CPEDataset
diff --git a/src/sec_certs/dataset/fips.py b/src/sec_certs/dataset/fips.py
index 68d027d0..ce7563a0 100644
--- a/src/sec_certs/dataset/fips.py
+++ b/src/sec_certs/dataset/fips.py
@@ -15,7 +15,7 @@ from sec_certs import constants
from sec_certs.config.configuration import config
from sec_certs.dataset.cpe import CPEDataset
from sec_certs.dataset.cve import CVEDataset
-from sec_certs.dataset.dataset import AuxillaryDatasets, Dataset
+from sec_certs.dataset.dataset import AuxiliaryDatasets, Dataset
from sec_certs.dataset.fips_algorithm import FIPSAlgorithmDataset
from sec_certs.model.reference_finder import ReferenceFinder
from sec_certs.model.transitive_vulnerability_finder import TransitiveVulnerabilityFinder
@@ -28,13 +28,13 @@ from sec_certs.utils.helpers import fips_dgst
logger = logging.getLogger(__name__)
-class FIPSAuxillaryDatasets(AuxillaryDatasets):
+class FIPSAuxiliaryDatasets(AuxiliaryDatasets):
cpe_dset: CPEDataset | None = None
cve_dset: CVEDataset | None = None
algorithm_dset: FIPSAlgorithmDataset | None = None
-class FIPSDataset(Dataset[FIPSCertificate, FIPSAuxillaryDatasets], ComplexSerializableType):
+class FIPSDataset(Dataset[FIPSCertificate, FIPSAuxiliaryDatasets], ComplexSerializableType):
"""
Class for processing of FIPSCertificate samples. Inherits from `ComplexSerializableType` and base abstract `Dataset` class.
"""
@@ -46,7 +46,7 @@ class FIPSDataset(Dataset[FIPSCertificate, FIPSAuxillaryDatasets], ComplexSerial
name: str | None = None,
description: str = "",
state: Dataset.DatasetInternalState | None = None,
- auxillary_datasets: FIPSAuxillaryDatasets | None = None,
+ auxiliary_datasets: FIPSAuxiliaryDatasets | None = None,
):
self.certs = certs
self.timestamp = datetime.datetime.now()
@@ -54,8 +54,8 @@ class FIPSDataset(Dataset[FIPSCertificate, FIPSAuxillaryDatasets], ComplexSerial
self.name = name if name else type(self).__name__ + " dataset"
self.description = description if description else datetime.datetime.now().strftime("%d/%m/%Y %H:%M:%S")
self.state = state if state else self.DatasetInternalState()
- self.auxillary_datasets: FIPSAuxillaryDatasets = (
- auxillary_datasets if auxillary_datasets else FIPSAuxillaryDatasets()
+ self.auxiliary_datasets: FIPSAuxiliaryDatasets = (
+ auxiliary_datasets if auxiliary_datasets else FIPSAuxiliaryDatasets()
)
self.root_dir = Path(root_dir)
@@ -84,7 +84,7 @@ class FIPSDataset(Dataset[FIPSCertificate, FIPSAuxillaryDatasets], ComplexSerial
@property
def algorithm_dataset_path(self) -> Path:
- return self.auxillary_datasets_dir / "algorithms.json"
+ return self.auxiliary_datasets_dir / "algorithms.json"
def __getitem__(self, item: str) -> FIPSCertificate:
try:
@@ -222,8 +222,8 @@ class FIPSDataset(Dataset[FIPSCertificate, FIPSAuxillaryDatasets], ComplexSerial
def _set_local_paths(self) -> None:
super()._set_local_paths()
- if self.auxillary_datasets.algorithm_dset:
- self.auxillary_datasets.algorithm_dset.json_path = self.algorithm_dataset_path
+ if self.auxiliary_datasets.algorithm_dset:
+ self.auxiliary_datasets.algorithm_dset.json_path = self.algorithm_dataset_path
cert: FIPSCertificate
for cert in self.certs.values():
@@ -247,9 +247,9 @@ class FIPSDataset(Dataset[FIPSCertificate, FIPSAuxillaryDatasets], ComplexSerial
self.state.meta_sources_parsed = True
@serialize
- def process_auxillary_datasets(self, download_fresh: bool = False) -> None:
- super().process_auxillary_datasets(download_fresh)
- self.auxillary_datasets.algorithm_dset = self._prepare_algorithm_dataset(download_fresh)
+ def process_auxiliary_datasets(self, download_fresh: bool = False) -> None:
+ super().process_auxiliary_datasets(download_fresh)
+ self.auxiliary_datasets.algorithm_dset = self._prepare_algorithm_dataset(download_fresh)
def _prepare_algorithm_dataset(self, download_fresh_algs: bool = False) -> FIPSAlgorithmDataset:
logger.info("Preparing FIPSAlgorithm dataset.")
@@ -297,7 +297,7 @@ class FIPSDataset(Dataset[FIPSCertificate, FIPSAuxillaryDatasets], ComplexSerial
cert.prune_referenced_cert_ids()
# Previously, a following procedure was used to prune reference_candidates:
- # - A set of algorithms was obtained via self.auxillary_datasets.algorithm_dset.get_algorithms_by_id(reference_candidate)
+ # - A set of algorithms was obtained via self.auxiliary_datasets.algorithm_dset.get_algorithms_by_id(reference_candidate)
# - If any of these algorithms had the same vendor as the reference_candidate, the candidate was rejected
# - The rationale is that if an ID appears in a certificate s.t. an algorithm with the same ID was produced by the same vendor, the reference likely refers to alg.
# - Such reference should then be discarded.
diff --git a/src/sec_certs/dataset/cc.py b/src/sec_certs/dataset/cc.py
index c8038d0c..c2849772 100644
--- a/src/sec_certs/dataset/cc.py
+++ b/src/sec_certs/dataset/cc.py
@@ -21,7 +21,7 @@ from sec_certs import constants
from sec_certs.config.configuration import config
from sec_certs.dataset.cpe import CPEDataset
from sec_certs.dataset.cve import CVEDataset
-from sec_certs.dataset.dataset import AuxillaryDatasets, Dataset, logger
+from sec_certs.dataset.dataset import AuxiliaryDatasets, Dataset, logger
from sec_certs.dataset.protection_profile import ProtectionProfileDataset
from sec_certs.model.reference_finder import ReferenceFinder
from sec_certs.model.sar_transformer import SARTransformer
@@ -37,14 +37,14 @@ from sec_certs.utils.sanitization import sanitize_navigable_string as sns
@dataclass
-class CCAuxillaryDatasets(AuxillaryDatasets):
+class CCAuxiliaryDatasets(AuxiliaryDatasets):
cpe_dset: CPEDataset | None = None
cve_dset: CVEDataset | None = None
pp_dset: ProtectionProfileDataset | None = None
mu_dset: CCDatasetMaintenanceUpdates | None = None
-class CCDataset(Dataset[CCCertificate, CCAuxillaryDatasets], ComplexSerializableType):
+class CCDataset(Dataset[CCCertificate, CCAuxiliaryDatasets], ComplexSerializableType):
"""
Class that holds CCCertificate. Serializable into json, pandas, dictionary. Conveys basic certificate manipulations
and dataset transformations. Many private methods that perform internal operations, feel free to exploit them.
@@ -57,7 +57,7 @@ class CCDataset(Dataset[CCCertificate, CCAuxillaryDatasets], ComplexSerializable
name: str | None = None,
description: str = "",
state: Dataset.DatasetInternalState | None = None,
- auxillary_datasets: CCAuxillaryDatasets | None = None,
+ auxiliary_datasets: CCAuxiliaryDatasets | None = None,
):
self.certs = certs
self.timestamp = datetime.now()
@@ -66,8 +66,8 @@ class CCDataset(Dataset[CCCertificate, CCAuxillaryDatasets], ComplexSerializable
self.description = description if description else datetime.now().strftime("%d/%m/%Y %H:%M:%S")
self.state = state if state else self.DatasetInternalState()
- self.auxillary_datasets: CCAuxillaryDatasets = (
- auxillary_datasets if auxillary_datasets else CCAuxillaryDatasets()
+ self.auxiliary_datasets: CCAuxiliaryDatasets = (
+ auxiliary_datasets if auxiliary_datasets else CCAuxiliaryDatasets()
)
self.root_dir = Path(root_dir)
@@ -144,14 +144,14 @@ class CCDataset(Dataset[CCCertificate, CCAuxillaryDatasets], ComplexSerializable
"""
Returns directory that holds files associated with Protection profiles
"""
- return self.auxillary_datasets_dir / "pp_dataset.json"
+ return self.auxiliary_datasets_dir / "pp_dataset.json"
@property
def mu_dataset_dir(self) -> Path:
"""
Returns directory that holds dataset of maintenance updates
"""
- return self.auxillary_datasets_dir / "maintenances"
+ return self.auxiliary_datasets_dir / "maintenances"
@property
def mu_dataset_path(self) -> Path:
@@ -220,15 +220,15 @@ class CCDataset(Dataset[CCCertificate, CCAuxillaryDatasets], ComplexSerializable
def _set_local_paths(self):
super()._set_local_paths()
- if self.auxillary_datasets.pp_dset:
- self.auxillary_datasets.pp_dset.json_path = self.pp_dataset_path
+ if self.auxiliary_datasets.pp_dset:
+ self.auxiliary_datasets.pp_dset.json_path = self.pp_dataset_path
- if self.auxillary_datasets.mu_dset:
- self.auxillary_datasets.mu_dset.root_dir = self.mu_dataset_dir
+ if self.auxiliary_datasets.mu_dset:
+ self.auxiliary_datasets.mu_dset.root_dir = self.mu_dataset_dir
for cert in self:
cert.set_local_paths(self.reports_pdf_dir, self.targets_pdf_dir, self.reports_txt_dir, self.targets_txt_dir)
# TODO: This forgets to set local paths for other auxillary datasets
def _merge_certs(self, certs: dict[str, CCCertificate], cert_source: str | None = None) -> None:
"""
@@ -733,14 +733,14 @@ class CCDataset(Dataset[CCCertificate, CCAuxillaryDatasets], ComplexSerializable
setattr(self.certs[dgst].heuristics, dep_attr, finder.predict_single_cert(dgst, keep_unknowns=False))
@serialize
- def process_auxillary_datasets(self, download_fresh: bool = False) -> None:
+ def process_auxiliary_datasets(self, download_fresh: bool = False) -> None:
"""
Processes all auxillary datasets needed during computation. On top of base-class processing,
CC handles protection profiles and maintenance updates.
"""
- super().process_auxillary_datasets(download_fresh)
- self.auxillary_datasets.pp_dset = self.process_protection_profiles(to_download=download_fresh)
- self.auxillary_datasets.mu_dset = self.process_maintenance_updates(to_download=download_fresh)
+ super().process_auxiliary_datasets(download_fresh)
+ self.auxiliary_datasets.pp_dset = self.process_protection_profiles(to_download=download_fresh)
+ self.auxiliary_datasets.mu_dset = self.process_maintenance_updates(to_download=download_fresh)
def process_protection_profiles(
self, to_download: bool = True, keep_metadata: bool = True
@@ -755,7 +755,7 @@ class CCDataset(Dataset[CCCertificate, CCAuxillaryDatasets], ComplexSerializable
"""
logger.info("Processing protection profiles.")
- self.auxillary_datasets_dir.mkdir(parents=True, exist_ok=True)
+ self.auxiliary_datasets_dir.mkdir(parents=True, exist_ok=True)
if to_download or not self.pp_dataset_path.exists():
pp_dataset = ProtectionProfileDataset.from_web(self.pp_dataset_path)
@@ -833,7 +833,7 @@ class CCDatasetMaintenanceUpdates(CCDataset, ComplexSerializableType):
def compute_related_cves(self) -> None:
raise NotImplementedError
- def process_auxillary_datasets(self, download_fresh: bool = False) -> None:
+ def process_auxiliary_datasets(self, download_fresh: bool = False) -> None:
raise NotImplementedError
def analyze_certificates(self) -> None:
@@ -220,15 +220,15 @@ class CCDataset(Dataset[CCCertificate, CCAuxillaryDatasets], ComplexSerializable
for cert in self:
cert.set_local_paths(self.reports_pdf_dir, self.targets_pdf_dir, self.reports_txt_dir, self.targets_txt_dir)
- # TODO: This forgets to set local paths for other auxillary datasets
+ # TODO: This forgets to set local paths for other auxiliary datasets
def _merge_certs(self, certs: dict[str, CCCertificate], cert_source: str | None = None) -> None:
"""
@@ -733,14 +733,14 @@ class CCDataset(Dataset[CCCertificate, CCAuxillaryDatasets], ComplexSerializable
"""
- Processes all auxillary datasets needed during computation. On top of base-class processing,
+ Processes all auxiliary datasets needed during computation. On top of base-class processing,
CC handles protection profiles and maintenance updates.
"""
diff --git a/src/sec_certs/dataset/dataset.py b/src/sec_certs/dataset/dataset.py
index 0066646b..711d3592 100644
--- a/src/sec_certs/dataset/dataset.py
+++ b/src/sec_certs/dataset/dataset.py
@@ -29,17 +29,17 @@ logger = logging.getLogger(__name__)
@dataclass
-class AuxillaryDatasets:
+class AuxiliaryDatasets:
cpe_dset: CPEDataset | None = None
cve_dset: CVEDataset | None = None
CertSubType = TypeVar("CertSubType", bound=Certificate)
-AuxillaryDatasetsSubType = TypeVar("AuxillaryDatasetsSubType", bound=AuxillaryDatasets)
+AuxiliaryDatasetsSubType = TypeVar("AuxiliaryDatasetsSubType", bound=AuxiliaryDatasets)
DatasetSubType = TypeVar("DatasetSubType", bound="Dataset")
-class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializableType, ABC):
+class Dataset(Generic[CertSubType, AuxiliaryDatasetsSubType], ComplexSerializableType, ABC):
"""
Base class for dataset of certificates from CC and FIPS 140 schemes. Layouts public
functions, the processing pipeline and common operations on the dataset and certs.
@@ -50,7 +50,7 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
meta_sources_parsed: bool = False
artifacts_downloaded: bool = False
pdfs_converted: bool = False
- auxillary_datasets_processed: bool = False
+ auxiliary_datasets_processed: bool = False
certs_analyzed: bool = False
def __bool__(self):
@@ -63,7 +63,7 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
name: str | None = None,
description: str = "",
state: DatasetInternalState | None = None,
- auxillary_datasets: AuxillaryDatasetsSubType | None = None,
+ auxiliary_datasets: AuxiliaryDatasetsSubType | None = None,
):
self.certs = certs
@@ -73,10 +73,10 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
self.description = description if description else "No description provided"
self.state = state if state else self.DatasetInternalState()
- if not auxillary_datasets:
- self.auxillary_datasets = AuxillaryDatasets()
+ if not auxiliary_datasets:
+ self.auxiliary_datasets = AuxiliaryDatasets()
else:
- self.auxillary_datasets = auxillary_datasets
+ self.auxiliary_datasets = auxiliary_datasets
self.root_dir = Path(root_dir)
@@ -108,11 +108,11 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
return self.root_dir / "web"
@property
- def auxillary_datasets_dir(self) -> Path:
+ def auxiliary_datasets_dir(self) -> Path:
"""
Path to directory with auxillary datasets.
"""
- return self.root_dir / "auxillary_datasets"
+ return self.root_dir / "auxiliary_datasets"
@property
def certs_dir(self) -> Path:
@@ -123,15 +123,15 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
@property
def cpe_dataset_path(self) -> Path:
- return self.auxillary_datasets_dir / "cpe_dataset.json"
+ return self.auxiliary_datasets_dir / "cpe_dataset.json"
@property
def cve_dataset_path(self) -> Path:
- return self.auxillary_datasets_dir / "cve_dataset.json"
+ return self.auxiliary_datasets_dir / "cve_dataset.json"
@property
def nist_cve_cpe_matching_dset_path(self) -> Path:
- return self.auxillary_datasets_dir / "nvdcpematch-1.0.json"
+ return self.auxiliary_datasets_dir / "nvdcpematch-1.0.json"
@property
def json_path(self) -> Path:
@@ -205,10 +205,10 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
return dset
def _set_local_paths(self) -> None:
- if self.auxillary_datasets.cpe_dset:
- self.auxillary_datasets.cpe_dset.json_path = self.cpe_dataset_path
- if self.auxillary_datasets.cve_dset:
- self.auxillary_datasets.cve_dset.json_path = self.cve_dataset_path
+ if self.auxiliary_datasets.cpe_dset:
+ self.auxiliary_datasets.cpe_dset.json_path = self.cpe_dataset_path
+ if self.auxiliary_datasets.cve_dset:
+ self.auxiliary_datasets.cve_dset.json_path = self.cve_dataset_path
def move_dataset(self, new_root_dir: str | Path) -> None:
"""
@@ -249,15 +249,15 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
@serialize
@abstractmethod
- def process_auxillary_datasets(self, download_fresh: bool = False) -> None:
+ def process_auxiliary_datasets(self, download_fresh: bool = False) -> None:
"""
Processes all auxillary datasets (CPE, CVE, ...) that are required during computation.
"""
- logger.info("Processing auxillary datasets.")
- self.auxillary_datasets_dir.mkdir(parents=True, exist_ok=True)
- self.auxillary_datasets.cpe_dset = self._prepare_cpe_dataset(download_fresh)
- self.auxillary_datasets.cve_dset = self._prepare_cve_dataset(download_fresh_cves=download_fresh)
- self.state.auxillary_datasets_processed = True
+ logger.info("Processing auxiliary datasets.")
+ self.auxiliary_datasets_dir.mkdir(parents=True, exist_ok=True)
+ self.auxiliary_datasets.cpe_dset = self._prepare_cpe_dataset(download_fresh)
+ self.auxiliary_datasets.cve_dset = self._prepare_cve_dataset(download_fresh_cves=download_fresh)
+ self.state.auxiliary_datasets_processed = True
@serialize
def download_all_artifacts(self, fresh: bool = True) -> None:
@@ -311,9 +311,9 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
"Attempting run analysis of txt files while not having the pdf->txt conversion done. Returning."
)
return
- if not self.state.auxillary_datasets_processed:
+ if not self.state.auxiliary_datasets_processed:
logger.info(
- "Attempting to run analysis of certifies while not having the auxillary datasets processed. Returning."
+ "Attempting to run analysis of certifies while not having the auxiliary datasets processed. Returning."
)
logger.info("Analyzing certificates.")
@@ -345,8 +345,8 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
def _prepare_cpe_dataset(self, download_fresh_cpes: bool = False) -> CPEDataset:
logger.info("Preparing CPE dataset.")
- if not self.auxillary_datasets_dir.exists():
- self.auxillary_datasets_dir.mkdir(parents=True)
+ if not self.auxiliary_datasets_dir.exists():
+ self.auxiliary_datasets_dir.mkdir(parents=True)
if not self.cpe_dataset_path.exists() or download_fresh_cpes is True:
cpe_dataset = CPEDataset.from_web(self.cpe_dataset_path)
@@ -360,8 +360,8 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
self, download_fresh_cves: bool = False, use_nist_cpe_matching_dict: bool = True
) -> CVEDataset:
logger.info("Preparing CVE dataset.")
- if not self.auxillary_datasets_dir.exists():
- self.auxillary_datasets_dir.mkdir(parents=True)
+ if not self.auxiliary_datasets_dir.exists():
+ self.auxiliary_datasets_dir.mkdir(parents=True)
if not self.cve_dataset_path.exists() or download_fresh_cves is True:
cve_dataset = CVEDataset.from_web(json_path=self.cve_dataset_path)
@@ -406,18 +406,18 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
return True
logger.info("Computing heuristics: Finding CPE matches for certificates")
- if not self.auxillary_datasets.cpe_dset or download_fresh_cpes:
- self.auxillary_datasets.cpe_dset = self._prepare_cpe_dataset(download_fresh_cpes)
+ if not self.auxiliary_datasets.cpe_dset or download_fresh_cpes:
+ self.auxiliary_datasets.cpe_dset = self._prepare_cpe_dataset(download_fresh_cpes)
# Temporarily disabled, see: https://github.com/crocs-muni/sec-certs/issues/173
# if not cpe_dset.was_enhanced_with_vuln_cpes:
# self.auxillary_datasets.cve_dset = self._prepare_cve_dataset(download_fresh_cves=False)
# self.auxillary_datasets.cpe_dset.enhance_with_cpes_from_cve_dataset(cve_dset) # this also calls build_lookup_dicts() on cpe_dset
# else:
- # self.auxillary_datasets.cpe_dset.build_lookup_dicts()
+ # self.auxiliary_datasets.cpe_dset.build_lookup_dicts()
clf = CPEClassifier(config.cpe_matching_threshold, config.cpe_n_max_matches)
- clf.fit([x for x in self.auxillary_datasets.cpe_dset if filter_condition(x)])
+ clf.fit([x for x in self.auxiliary_datasets.cpe_dset if filter_condition(x)])
cert: CertSubType
for cert in tqdm(self, desc="Predicting CPE matches with the classifier"):
@@ -515,8 +515,8 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
Computes CVEs for the certificates, given their CPE matches.
"""
logger.info("Retrieving related CVEs to verified CPE matches")
- if download_fresh_cves or not self.auxillary_datasets.cve_dset:
- self.auxillary_datasets.cve_dset = self._prepare_cve_dataset(
+ if download_fresh_cves or not self.auxiliary_datasets.cve_dset:
+ self.auxiliary_datasets.cve_dset = self._prepare_cve_dataset(
download_fresh_cves, use_nist_cpe_matching_dict
)
@@ -531,13 +531,13 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
return
relevant_cpes = set(itertools.chain.from_iterable(x.heuristics.cpe_matches for x in cpe_rich_certs))
- self.auxillary_datasets.cve_dset.filter_related_cpes(relevant_cpes)
+ self.auxiliary_datasets.cve_dset.filter_related_cpes(relevant_cpes)
cert: Certificate
for cert in tqdm(cpe_rich_certs, desc="Computing related CVES"):
if cert.heuristics.cpe_matches:
related_cves = [
- self.auxillary_datasets.cve_dset.get_cve_ids_for_cpe_uri(x) for x in cert.heuristics.cpe_matches
+ self.auxiliary_datasets.cve_dset.get_cve_ids_for_cpe_uri(x) for x in cert.heuristics.cpe_matches
]
related_cves = list(filter(lambda x: x is not None, related_cves))
if related_cves:
@@ -108,11 +108,11 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
"""
- Path to directory with auxillary datasets.
+ Path to directory with auxiliary datasets.
"""
@@ -249,15 +249,15 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
"""
- Processes all auxillary datasets (CPE, CVE, ...) that are required during computation.
+ Processes all auxiliary datasets (CPE, CVE, ...) that are required during computation.
"""
@@ -406,18 +406,18 @@ class Dataset(Generic[CertSubType, AuxillaryDatasetsSubType], ComplexSerializabl
# Temporarily disabled, see: https://github.com/crocs-muni/sec-certs/issues/173
# if not cpe_dset.was_enhanced_with_vuln_cpes:
- # self.auxillary_datasets.cve_dset = self._prepare_cve_dataset(download_fresh_cves=False)
- # self.auxillary_datasets.cpe_dset.enhance_with_cpes_from_cve_dataset(cve_dset) # this also calls build_lookup_dicts() on cpe_dset
+ # self.auxiliary_datasets.cve_dset = self._prepare_cve_dataset(download_fresh_cves=False)
+ # self.auxiliary_datasets.cpe_dset.enhance_with_cpes_from_cve_dataset(cve_dset) # this also calls build_lookup_dicts() on cpe_dset
# else: